# PROJECT: file_utilities

This is a program to turn a lyrics-like string to .lrc file.

## BEFORE START

'file_utilities' is licensed under [MIT](./LICENSE).

Copyright © 2025 by Creeper32767

## requirements:

1. python environment
2. openpyxl

## functions

```
dict_utils
    get_key_by_value
    get_key_by_value_with_order
    get_key_with_order

json_utils
    BaseJsonOperator
    International (Specialized for i18n service)

logging_utils
    Logging

xlsx_utils
    XlsxOperator
```

## Installation

```bash
pip install file_utilities
```

## ISSUES

Please give us your ideas through the 'issues' part on GitHub.
